@@ -368,9 +368,53 @@
 //!     // They'll be rendered sequentially.
 //!     #[label("This is bad")]
 //!     snip2: (usize, usize), // `(usize, usize)` is `Into<SourceSpan>`!
+//!
+//!     // Snippets can be optional, by using Option:
+//!     #[label("some text")]
+//!     snip3: Option<SourceSpan>,
+//!
+//!     // with or without label text
+//!     #[label]
+//!     snip4: Option<SourceSpan>,
 //! }
 //! ```
 //!
+//! #### ... help text
+//! `miette` provides two facilities for supplying help text for your errors:
+//
+//! The first is the `#[help()]` format attribute that applies to structs or
+//! enum variants:
+//!
+//! ```rust
+//! use miette::Diagnostic;
+//! use thiserror::Error;
+//!
+//! #[derive(Debug, Diagnostic, Error)]
+//! #[error("welp")]
+//! #[diagnostic(help("try doing this instead"))]
+//! struct Foo;
+//! ```
+//!
+//! The other is by programmatically supplying the help text as a field to your
+//! diagnostic:
+//!
+//! ```rust
+//! use miette::Diagnostic;
+//! use thiserror::Error;
+//!
+//! #[derive(Debug, Diagnostic, Error)]
+//! #[error("welp")]
+//! #[diagnostic()]
+//! struct Foo {
+//!     #[help]
+//!     advice: Option<String>, // Can also just be `String`
+//! }
+//!
+//! let err = Foo {
+//!     advice: Some("try doing this instead".to_string()),
+//! };
+//! ```
+//!
 //! ### ... multiple related errors
 //!
 //! `miette` supports collecting multiple errors into a single diagnostic, and
@@ -545,6 +589,8 @@ mod eyreish;
 #[cfg(feature = "fancy-no-backtrace")]
 mod handler;
 mod handlers;
+#[doc(hidden)]
+pub mod macro_helpers;
 mod named_source;
 #[cfg(feature = "fancy")]
 mod panic;
